/*******************************************************************************

  Copyright(c) 2003-2004 Aurelien Reynaud.

  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
  Software Foundation; either version 2 of the License, or (at your option)
  any later version.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  more details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 59
  Temple Place - Suite 330, Boston, MA  02111-1307, USA.

  The full GNU General Public License is included in this distribution in the
  file called COPYING.

*******************************************************************************/

extern cell_t fullchar_null;

int history_init(int, int, int, int, int);
void history_exit();
#ifndef DISABLE_RESIZE
int history_add_columns(int);
int history_add_lines(int);
#endif
void history_write_char(int, int, cell_t);
void history_delete_chars(int, int, unsigned int);
void history_insert_chars(int, int, unsigned int);
void history_erase_chars(int, int, unsigned int);
void history_erase_line_from(int, int);
void history_erase_line_to(int, int);
void history_erase_line(int);
int history_page_up();
int history_page_down();
void history_scroll_down_region(int, int, int);
void history_scroll_up(int);
void history_scroll_up_region(int, int, int);
void history_get_line(int, cell_t**, int*, int*);
cell_t history_get_char(int, int);
